#!/usr/bin/env python

import shutil
import sys
import subprocess

print "Copying binaries"
try:
  shutil.copyfile("%s/ssher.py" % sys.argv[1], '/usr/bin/ssher')
  subprocess.call(['chmod', 'a+x', "/usr/bin/ssher"])
except IOError:
  print "You don' have permissions to perform this installation. Please, run this installation as root"


#!/usr/bin/env python
#-*- conding: utf-8 -*-
import sys
import os
import getpass


from ssher import Config, Server
Config = Config.Config
Server = Server.Server
from pybles import pybles
Pyble  = pybles.Pyble


class SSHER( object ):

    def __init__( self ):

        try:
            f = open('/home/%s/.ssher.cfg' % getpass.getuser(), 'r')
        except:
            print "Please, before use configure ~/.ssher.cfg"
            sys.exit(-1)

        self.config   = Config('/home/%s/.ssher.cfg' % getpass.getuser())
        self.servers  = list()
        self.internal = self.config.get_internal_config()

    def __generateHosts( self ):
        index = 0
        for server in self.config.get_servers():
            self.servers.append( Server( index,
                                         server['username'], 
                                         server['hostname'],
                                         server['ip'],
                                         server['tunnel'],
                                         server['port'],
                                         server['formal'],
                                         server['group']
                                       ))

            index += 1

        return index

    def __showServersList( self, pro=False, group=None ):
        PB = Pyble()

        if pro:
            PB.add_column('ID')
            PB.add_column('HOSTNAME')
            PB.add_column('IP')
            PB.add_column('USERNAME')
            PB.add_column('GROUP')
            PB.add_column('TUNNEL')
            PB.add_column('PORT')
            PB.add_column('FORMAL NAME')

            for server in self.servers:
                tunnel = None
                
                if server.get_tunnel() == "None":
                    tunnel = "-"
                else:
                    tunnel = server.get_tunnel()

                PB.add_line([server.get_id(), server.get_hostname(), server.get_ip(),
                             server.get_username(), server.get_group(), tunnel, server.get_port(),
                             server.get_formal()])

            PB.set_color(bool(self.internal['color']))
            PB.show_table()
        else:

            PB.add_column('ID')
            PB.add_column('HOSTNAME')
            PB.add_column('IP')
            PB.add_column('GROUP')

            for server in self.servers:
                tunnel = None
                if server.get_tunnel() == "None":
                    tunnel = "-"
                else:
                    tunnel = server.get_tunnel()

                if group is not None:

                    try:
                        groups = group.split(',')

                        for ggg in groups:
                            if server.get_group() == ggg:
                                PB.add_line([server.get_id(), server.get_hostname(), 
                                             server.get_ip(), server.get_group()])

                    except:
                        if server.get_group() == group:
                            PB.add_line([server.get_id(), server.get_hostname(), 
                                         server.get_ip(), server.get_group()])
                else:
                    PB.add_line([server.get_id(), server.get_hostname(), 
                                 server.get_ip(), server.get_group()])                    

            PB.set_color(bool(self.internal['color']))
            PB.show_table()


    def __getServerById( self, id ):
        for server in self.servers:
            if server.id == id:
                return server

    def __getServerByName( self, name ):
        for server in self.servers:
            if server.hostname == name:
                return server

    def __sshConnect( self, server ):
        if server.get_tunnel() == 'None':
            if server.get_port() != 'None':
                os.system( "ssh %s@%s -p %s" % ( server.get_username(), server.get_ip(), server.get_port() ) )

        else:
            print "ssh %s@%s -L %s" % ( server.get_username(), 
                                        server.get_ip(),
                                        server.get_tunnel()
                                      )
            if server.get_port() == 'None':
                os.system( "ssh %s@%s -L %s" % ( server.get_username(), 
                                                 server.get_ip(),
                                                 server.get_tunnel() ) )
            else:
                os.system( "ssh %s@%s -L %s -p %s" % ( server.get_username(), 
                                                 server.get_ip(),
                                                 server.get_tunnel(),
                                                 server.get_port() ) )

    def main( self, args ):
        count = self.__generateHosts()

        try:
            if args[1]   == '-l':
                self.__showServersList()
                return 0
            if args[1]   == '-L':
                self.__showServersList(pro=True)
                return 0
            if args[1]   == '-g':
                self.__showServersList(group=args[2])
                return 0
            elif args[1] == '-h':
                print "SSHer"
                print "  -h - Show this help"
                print "  -l - List available servers"
                print "  -L - List available servers (special still in devel)"
                print "  -g - Show only servers belonging to the given group"
                print "NONE - List available servers"
                print "  id - Start connection number id"
                return 0
            else:
                try:
                    if int( args[1] ) >= count:
                        print "Server not found"
                        return -1
                    else:
                        server = self.__getServerById( int( args[1] ) )
                        print "establishing connection to: %s" % server
                        self.__sshConnect( server )
                except ValueError:
                    server = self.__getServerByName( args[1] )
                    print "establishing connection to: %s" % server
                    self.__sshConnect( server )
        except IndexError:
            self.__showServersList()


if __name__ == '__main__':
    ssher = SSHER()

    sys.exit( ssher.main( sys.argv ) )



#!/usr/bin/env python
#-*- conding: utf-8 -*-
import ConfigParser
import sys

class Config( object ):

    def __init__( self, configfile ):
        self.configfile = configfile
        self.config     = ConfigParser.ConfigParser()
        self.config.read( configfile )

    def get_servers( self ):
        servers = list()

        try:
            for section in self.config.sections():
                if section != "ssher":
                    servers.append( { 'hostname': self.config.get( section, 'hostname' ),
                                      'username': self.config.get( section, 'username' ),
                                      'ip'      : self.config.get( section, 'ip' ),
                                      'tunnel'  : self.config.get( section, 'tunnel'),
                                      'port'    : self.config.get( section, 'port'),
                                      'formal'  : self.config.get( section, 'formal'),
                                      'group'   : self.config.get( section, 'group'),
                                   }
                                  )
        except Exception, msg:
            print "The following error have been encountered in the configuration file: %s" % msg

            sys.exit(-1)

        return servers

    def get_internal_config( self ):
        values = {'color': self.config.getboolean('ssher', 'color')}
        return values




#!/usr/bin/env python
#-*- conding: utf-8 -*-


class Server( object ):

    def __init__( self, id, username, hostname, ip, 
                  tunnel=None, port=None, formal=None,
                  group=None ):
        self.id       = id
        self.username = username
        self.hostname = hostname
        self.ip       = ip
        self.tunnel   = tunnel
        self.port     = port
        self.formal   = formal
        self.group    = group

    def __str__( self ):
        if self.tunnel == 'None':
            return "%s %s@%s" % (self.id, self.username, self.hostname)
        else:
            return "%s %s@%s -L %s" % (self.id, self.username, self.hostname, self.tunnel)

    def get_username( self ):
        return self.username

    def get_hostname( self ):
        return self.hostname

    def get_ip( self ):
        return self.ip

    def get_id( self ):
        return self.id

    def get_tunnel( self ):
        """
        (localport, remoteip, remoteport)
        """
        return self.tunnel

    def get_port( self ):
        return self.port

    def get_formal( self ):
        return self.formal

    def get_group( self ):
        return self.group

    def set_tunnel( self, tunnel ):
        self.tunnel = tunnel

    



#!/usr/bin/env python

import os
import sys
#from distutils.core import setup
from setuptools import setup
from distutils.command.install import install as _install

def _post_install(dir):
    from subprocess import call
    print os.path.join(dir, 'ssher')
    call([sys.executable, 'create_bin.py', os.path.join(dir, 'ssher')],
         cwd=os.path.join(dir, 'ssher'))


class install(_install):
    def run(self):
        _install.run(self)
        self.execute(_post_install, (self.install_lib,),
                     msg="Running post install task")


setup(
    name='SSHer',
    version='1.0.3',
    description='Multi ssh connection launcher',
    author='Guido Accardo',
    author_email='gaccardo@gmail.com',
    cmdclass={'install': install},
    install_requires=['Pybles >= 1.0.10'],
    packages=['ssher'])
